@@ -53,6 +53,18 @@
 #'   when a numeric has an interaction with a factor.  Acceptable inputs
 #'   are \code{"term"}, \code{"term_plain"}, and \code{"label"}.
 #'   See the full documentation for the unexported function \code{\link{tidy_levels_labels}}.
+#' @param caption A character string giving the caption for the table.
+#' @param float A logical used only in LaTeX output.  When \code{TRUE}, the table is 
+#'   set within a \code{table} environment.  The default is \code{TRUE}, as with 
+#'   \code{xtable}.
+#' @param longtable Allows the user to print a table in multiple sections.  
+#'     This is useful when 
+#'     a table has more rows than will fit on a printed page.  Acceptable inputs are \code{FALSE},
+#'     indicating that only one table is printed (default); \code{TRUE} that the table should be 
+#'     split into multiple tables with the default number of rows per table (see "Longtable"); or a 
+#'     positive integer indicating how many rows per table to include. All other values are 
+#'     interpreted as \code{FALSE}.  In LaTeX output, remember that after each section, a page 
+#'     break is forced. This setting may also be set from \code{sprinkle}. 
 #' @param ... Additional arguments to pass to \code{tidy}
 #' 
 #' @details The \code{head} object describes what each column of the table
@@ -83,6 +95,14 @@
 #'   \code{longtable} argument in the \code{\link{sprinkle}} function can change this
 #'   setting.
 #'   
+#'   The \code{table_width} element is specific to LaTeX tables.  This is a reference
+#'   value for when column widths are specified in terms of the \code{\%} units.  For
+#'   example, a column width of \code{20\%} will be defined as \code{table_width * .20}.
+#'   The value in \code{table_width} is assumed to be in inches and defaults to 6.
+#'   
+#'   The \code{tabcolsep} object determines the spacing between columns in a 
+#'   LaTeX table in pt.  By default, it is set at 6.
+#'   
 #'   The \code{print_method} object determines how the table is rendered when 
 #'   the \code{print} method is invoked.  The default is to print to the 
 #'   console.
@@ -110,7 +130,10 @@ dust <- function(object, ...,
                  glance_foot = FALSE, glance_stats = NULL, 
                  col_pairs = 2, byrow = FALSE,
                  descriptors = "term", 
-                 numeric_level = c("term", "term_plain", "label"))
+                 numeric_level = c("term", "term_plain", "label"),
+                 caption = NULL,
+                 float = TRUE,
+                 longtable = FALSE)
 {
   Check <- ArgumentCheck::newArgCheck()
   
@@ -118,7 +141,7 @@ dust <- function(object, ...,
   #* as given.  All other objects are tidied.
   if (!inherits(object, "data.frame") | tidy_df) 
     tidy_object <- broom::tidy(object, ...)
-  
+
   else if (inherits(object, "data.frame")){
     if (inherits(object, "data.table"))
       object <- as.data.frame(object)
@@ -134,15 +157,23 @@ dust <- function(object, ...,
   }
 
   if (!inherits(object, "data.frame") & any(!descriptors %in% "term")){
+    nms <- names(tidy_object)
+    
     tidy_object <- tidy_levels_labels(object,
                                       descriptors = descriptors,
                                       numeric_level = numeric_level,
                                       argcheck = Check) %>%
-      dplyr::bind_cols(., tidy_object[, -1, drop = FALSE])
+      dplyr::left_join(tidy_object, .,
+                       by = c("term" = "term"))
+    
+    if (!"term" %in% descriptors)
+      nms <- nms[!nms %in% "term"]
+    
+    tidy_object <- dplyr::select_(tidy_object, .dots = c(descriptors, nms))
   }
   
   ArgumentCheck::finishArgCheck(Check)
- 
+
   #* Create the table head
   head <- as.data.frame(t(names(tidy_object)),
                         stringsAsFactors=FALSE)
@@ -159,7 +190,7 @@ dust <- function(object, ...,
   else {
     foot <- NULL
   }
-  
+
   #* Eventually, by default, glance statistics will be inserted into
   #* the 'foot' object.  Objects passed as data frames should not have
   #* glance statistics by default.  Perhaps an option for glance_df should
@@ -170,10 +201,14 @@ dust <- function(object, ...,
                  interfoot = NULL,
                  foot = foot,
                  border_collapse = TRUE,
-                 longtable = FALSE,
+                 caption = caption,
+                 float = float,
+                 longtable = longtable,
+                 table_width = 6,
+                 tabcolsep = 6,
                  print_method = getOption("pixiedust_print_method")),
             class = "dust")
-  
+
 }
 
 #***********************************************************
@@ -234,6 +269,7 @@ cell_attributes_frame <- function(nrow, ncol)
               halign = "",
               valign = "",
               bg = "",
+              font_family = "",
               font_color = "",
               font_size = "",
               font_size_units = "",
@@ -251,8 +287,9 @@ cell_attributes_frame <- function(nrow, ncol)
               colspan = 1,
               na_string = NA,
               stringsAsFactors=FALSE) %>%
-    mutate_(html_row = ~row,
-            html_col = ~col)
+    dplyr::mutate_(html_row = ~row,
+            html_col = ~col,
+            merge = ~FALSE)
 }
 
 
@@ -263,4 +300,4 @@ primaryClass <- function(x){
 }
 
 
-utils::globalVariables(".")
+utils::globalVariables(c(".", "term"))
